package labss.lang.il.model;

/**
 * E' l'intefaccia che deve essere implementata dalle costanti del linguaggio.<p/>
 *
 * Le classi che rappresentano le costanti intere e booleane devono implementare
 * questa interfaccia.<br/>
 * I metodi <tt>intValue()</tt> e <tt>booleanValue()</tt> servono per semplificare
 * la scrittura dei metodi <tt>evaluate()</tt> ed <tt>execute()</tt> delle classi
 * che rappresentano le espressioni e le istruzioni del linguaggio.
 * @author Riccardo Solmi
 * @version 1.0
 * @see LanguageFactory
 */

public interface Literal extends Expression {
    /**
     * Restituisce il valore intero rappresentato da questa costante.<br/>
     * Se la costante non rappresenta un intero, l'esecuzione di questo
     * metodo deve provocare una eccezione di tipo <tt>IllegalArgumentException</tt>.
     * @throws IllegalArgumentException se la costante non rappresenta un intero.
     */
	public int intValue();
    /**
     * Restituisce il valore booleano rappresentato da questa costante.<br/>
     * Se la costante non rappresenta un booleano, l'esecuzione di questo
     * metodo deve provocare una eccezione di tipo <tt>IllegalArgumentException</tt>.
     * @throws IllegalArgumentException se la costante non rappresenta un booleano.
     */
	public boolean booleanValue();
	
	public void setValue(int value);
	public void setValue(boolean value);
}